Make your first contribution to an open source project
============================================================

> There's a first time for everything.

![women programming](https://opensource.com/sites/default/files/styles/image-full-size/public/lead-images/collab-team-pair-programming-code-keyboard2.png?itok=WnKfsl-G "women programming")
Image by : [WOCinTech Chat][16]. Modified by Opensource.com. [CC BY-SA 4.0][17]

It's a common misconception that contributing to open source is difficult. You might think, "Sometimes I can't even understand my own code; how am I supposed to understand someone else's?"

Relax. Until last year, I thought the same thing. Reading and understanding someone else's code and writing your own on top of that can be a daunting task, but with the right resources, it isn't as hard as you might think.

The first step is to choose a project. This decision can be instrumental in turning a newbie programmer into a seasoned open sourcer.

Many amateur programmers interested in open source are advised to check out [Git][18], but that is not the best way to start. Git is maintained by uber-geeks with years of software development experience. It is a good place to find an open source project to contribute to, but it's not beginner-friendly. Most devs contributing to Git have enough experience that they do not need resources or detailed documentation. In this article, I'll provide a checklist of beginner-friendly features and some tips to make your first open source contribution easy.

### Understand the product

Before contributing to a project, you should understand how it works. To understand it, you need to try it for yourself. If you find the product interesting and useful, it is worth contributing to.

Too often, beginners try to contribute to a project without first using the software. They then get frustrated and give up. If you don't use the software, you can't understand how it works. If you don't know how it works, how can you fix a bug or write a new feature?

Remember: Try it, then hack it.

### Check the project's status

How active is the project?

If you send a pull request to an unmaintained or dormant project, your pull request (or PR) may never be reviewed or merged. Look for projects with lots of activity; that way you will get immediate feedback on your code and your contributions will not go to waste.

Here's how to tell if a project is active:

*   **Number of contributors:** A growing number of contributors indicates the developer community is interested and willing to accept new contributors.

*   **Frequency of commits:** Check the most recent commit date. If it was within the last week, or even month or two, the project is being maintained.

*   **Number of maintainers:** A higher number of maintainers means more potential mentors to guide you.

*   **Activity level in the chat room/IRC:** A busy chat room means quick replies to your queries.

### Resources for beginners

Coala is an example of an open sour project that has its own resources for tutorials and documentation, where you can also access its API (every class and method). The site also features an attractive UI that makes you want to read more.

**Documentation:** Developers of all levels need reliable, well-maintained documentation to understand the details of a project. Look for projects that offer solid documentation on [GitHub][19] (or wherever it is hosted) and on a separate site like [Read the Docs][20], with lots of examples that will help you dive deep into the code.

### [coala-newcomers_guide.png][2]

![Coala Newcomers' Guide screen](https://opensource.com/sites/default/files/styles/panopoly_image_original/public/images/life-uploads/coala-newcomers_guide.png?itok=G7mfPbXN "Coala Newcomers' Guide screen")

**Tutorials:** Tutorials that explain how to add features to a project are helpful for beginners (however, you may not find them for all projects). For example, coala offers [tutorials for writing  _bears_][21]  (Python wrappers for linting tools to perform code analysis).

### [coala_ui.png][3]

![Coala UI](https://opensource.com/sites/default/files/styles/panopoly_image_original/public/images/life-uploads/coala_ui.png?itok=LR02629W "Coala User Interface screenshot")

**Labeled issues:** For beginners who are just figuring out how to choose their first project, selecting an issue can be an even tougher task. Issues labeled "difficulty/low," "difficulty/newcomer," "good first issue," and "low-hanging fruit" can be perfect for newbies.

### [coala_labeled_issues.png][4]

![Coala labeled issues](https://opensource.com/sites/default/files/styles/panopoly_image_original/public/images/life-uploads/coala_labeled_issues.png?itok=74qSjG_T "Coala labeled issues")

### Miscellaneous factors

### [ci_logs.png][5]

![CI user pipeline log](https://opensource.com/sites/default/files/styles/panopoly_image_original/public/images/life-uploads/ci_logs.png?itok=J3V8gbc7 "CI user pipeline log")

*   **Maintainers' attitudes toward new contributors:** In my experience, most open sourcers are eager to help newcomers onboard their projects. However, you may also encounter some who are less welcoming (maybe even a bit rude) when you ask for help. Don't let them discourage you. Just because someone has more experience doesn't give them the right to be rude. There are plenty of others out there who want to help.

*   **Review process/structure:** Your PR will go through a number of reviews and changes by experienced developers and your peers—that's how you learn the most about software development. A project with a stringent review process enables you to grow as a developer by writing production-grade code.

*   **A robust CI pipeline:** Open source projects introduce beginners to continuous integration and deployment services. A robust CI pipeline will help you learn how to read and make sense of CI logs. It will also give you experience dealing with failing test cases and code coverage issues.

*   **Participation in code programs (Ex. [Google Summer Of Code][1]): **Participating organizations demonstrate a willingness to commit to the long-term development of a project. They also provide an opportunity for newcomers to gain real-world development experience and get paid for it. Most of the organizations that participate in such programs welcome newbies.

### 7 beginner-friendly organizations

*   [coala (Python)][7]

*   [oppia (Python, Django)][8]

*   [DuckDuckGo (Perl, JavaScript)][9]

*   [OpenGenus (JavaScript)][10]

*   [Kinto (Python, JavaScript)][11]

*   [FOSSASIA (Python, JavaScript)][12]

*   [Kubernetes (Go)][13]


### About the author

 [![](https://opensource.com/sites/default/files/styles/profile_pictures/public/pictures/img_20180309_001440858.jpg?itok=tG8yvrJF)][22] Palash Nigam - I'm a computer science undergrad from India who loves to hack on open source software and spend most of my time on GitHub. My current interests include backend web development, blockchains, and all things python.[More about me][14]

--------------------------------------------------------------------------------

via: https://opensource.com/article/18/4/get-started-open-source-project

作者：[ Palash Nigam ][a]
译者：[译者ID](https://github.com/译者ID)
校对：[校对者ID](https://github.com/校对者ID)

本文由 [LCTT](https://github.com/LCTT/TranslateProject) 原创编译，[Linux中国](https://linux.cn/) 荣誉推出

[a]:https://opensource.com/users/palash25
[1]:https://en.wikipedia.org/wiki/Google_Summer_of_Code
[2]:https://opensource.com/file/391211
[3]:https://opensource.com/file/391216
[4]:https://opensource.com/file/391226
[5]:https://opensource.com/file/391221
[6]:https://opensource.com/article/18/4/get-started-open-source-project?rate=i_d2neWpbOIJIAEjQKFExhe0U_sC6SiQgkm3c7ck8IM
[7]:https://github.com/coala/coala
[8]:https://github.com/oppia/oppia
[9]:https://github.com/duckduckgo/
[10]:https://github.com/OpenGenus/
[11]:https://github.com/kinto
[12]:https://github.com/fossasia/
[13]:https://github.com/kubernetes
[14]:https://opensource.com/users/palash25
[15]:https://opensource.com/user/212436/feed
[16]:https://www.flickr.com/photos/wocintechchat/25171528213/
[17]:https://creativecommons.org/licenses/by/4.0/
[18]:https://git-scm.com/
[19]:https://github.com/
[20]:https://readthedocs.org/
[21]:http://api.coala.io/en/latest/Developers/Writing_Linter_Bears.html
[22]:https://opensource.com/users/palash25
[23]:https://opensource.com/users/palash25
[24]:https://opensource.com/users/palash25
[25]:https://opensource.com/article/18/4/get-started-open-source-project#comments
[26]:https://opensource.com/tags/web-development
